# Набор некоторых функций которые станут лучше

### Модули которые могут потребоваться
    import pandas, pywin32, openpyxl

**links_main(name_file, key, sep=';')** - функция для работы с путями, ссылки, вводные данные хранятся в блокноте
